/**
 * Description: CmAddGoods控制器
 * Copyright:   Copyright (c)2015
 * Company:     江苏三六五网络股份有限公司
 *
 * @author: 江苏三六五网络股份有限公司
 * @version: 1.0
 * Create at:   2015-08-10 下午 17:06:04
 * <p>
 * Modification History:
 * Date         Author      Version     Description
 * ------------------------------------------------------------------
 * 2015-08-10   江苏三六五网络股份有限公司   1.0         Initial
 */
package com.house365.web.controller;

import com.house365.beans.entity.CmAddGoodsEntity;
import com.house365.beans.system.Page;
import com.house365.beans.vo.CmAddGoodsVo;
import com.house365.web.system.controller.BaseController;
import com.house365.web.util.StringUtils;
import com.house365.ws.beans.request.CmAddGoodsListRequest;
import com.house365.ws.beans.request.CmAddGoodsRequest;
import com.house365.ws.beans.response.CmAddGoodsListResponse;
import com.house365.ws.beans.response.CmAddGoodsResponse;
import com.house365.ws.interfaces.server.ICmAddGoods;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseStatus;
import org.springframework.web.servlet.mvc.support.RedirectAttributes;
import org.springside.modules.web.Servlets;

import javax.servlet.http.HttpServletRequest;
import javax.validation.Valid;
import java.util.Map;

/**
 * CmAddGoods控制器<br>
 *
 * @author 江苏三六五网络股份有限公司
 * @version 1.0, 2015-08-10
 * @see
 * @since 1.0
 */
@Controller
@RequestMapping("/cmaddgoods")
public class CmAddGoodsController extends BaseController {

    /**
     * 自动注入CmAddGoodsWS实现
     */
    @Autowired
    private ICmAddGoods cmAddGoods;

    /**
     * 去新增CmAddGoods
     *
     * @return 结果视图
     */
    @RequestMapping(value = "", params = "action=create")
    public String createForm(Model model) {
        model.addAttribute("action", "create");
        return getAutoUrl("form");
    }

    /**
     * 新增CmAddGoods
     *
     * @param vo     CmAddGoods页面表单对象
     * @param result 表单验证数据
     * @return 结果视图
     */
    @RequestMapping(value = "", method = {RequestMethod.POST})
    public String createCmAddGoods(@Valid CmAddGoodsVo vo, BindingResult result, RedirectAttributes redirectAttributes, Model model) {
        CmAddGoodsEntity entity = vo.getEntity();
        model.addAttribute("entity", entity);
        // subValidation(result, entity);
        // 表单验证无误,进行提交
        if (result.hasErrors()) {
            model.addAttribute("action", "create");
            addErrorMessage(model, result.getFieldError().getDefaultMessage());
            return getAutoUrl("form");
        } else {
            try {
                CmAddGoodsRequest request = new CmAddGoodsRequest();
                request.setEntity(entity);
                CmAddGoodsResponse response = cmAddGoods.addCmAddGoods(request);
                Integer id = response.getEntity().getId();
                return "redirect:/cmaddgoods/" + id;
            } catch (Exception ex) {
                addErrorMessage(model, ex.getMessage());
                model.addAttribute("action", "create");
                return getAutoUrl("form");
            }
        }
    }

    /**
     * 删除CmAddGoods
     *
     * @param id CmAddGoods页面表单对象唯一标识
     * @return 结果视图
     */
    @RequestMapping(value = "/{id}", method = {RequestMethod.DELETE})
    @ResponseStatus(HttpStatus.OK)
    public void delete(@PathVariable String id) {
        if (!StringUtils.isEmpty(id)) {
            if (id.contains(",")) {
                String[] ids = id.split(",");
                for (int i = 0; i < ids.length; i++) {
                    cmAddGoods.deleteCmAddGoodsById(Integer.valueOf(ids[i]));
                }
            } else {
                cmAddGoods.deleteCmAddGoodsById(Integer.valueOf(id));
            }
        }
    }

    /**
     * 去查看CmAddGoods
     *
     * @param id CmAddGoods页面表单对象唯一标识
     * @return 结果视图
     */
    @RequestMapping(value = "/{id}", method = {RequestMethod.GET})
    public String showForm(@PathVariable(value = "id") Integer id, Model model) {
        CmAddGoodsResponse response = cmAddGoods
                .getCmAddGoodsById(id);
        model.addAttribute("entity", response.getEntity());
        return getAutoUrl("form");
    }

    /**
     * 去修改CmAddGoods
     *
     * @param id CmAddGoods页面表单对象唯一标识
     * @return 结果视图
     */
    @RequestMapping(value = "/{id}", method = {RequestMethod.GET}, params = "action=edit")
    public String updateForm(@PathVariable(value = "id") Integer id, Model model) {
        CmAddGoodsResponse response = cmAddGoods.getCmAddGoodsById(id);
        model.addAttribute("entity", response.getEntity());
        model.addAttribute("action", "edit");
        return getAutoUrl("form");
    }

    /**
     * 修改CmAddGoods
     *
     * @param vo     CmAddGoods页面表单对象
     * @param result 表单验证数据
     * @return 结果视图
     */
    @RequestMapping(value = "/{id}", method = {RequestMethod.POST})
    public String updateCmAddGoods(@Valid CmAddGoodsVo vo, BindingResult result, @PathVariable Integer id, RedirectAttributes redirectAttributes, Model model) {
        CmAddGoodsEntity entity = vo.getEntity();
        model.addAttribute("entity", entity);
        // subValidation(result, entity);
        // 表单验证无误,进行提交
        if (result.hasErrors()) {
            model.addAttribute("action", "create");
            addErrorMessage(model, result.getFieldError().getDefaultMessage());
            return getAutoUrl("form");
        } else {
            try {
                CmAddGoodsRequest request = new CmAddGoodsRequest();
                request.setEntity(entity);
                cmAddGoods.updateCmAddGoods(request);
                redirectAttributes.addAttribute("message", "更新成功");
                return "redirect:/cmaddgoods/" + entity.getId();
            } catch (Exception ex) {
                addErrorMessage(model, ex.getMessage());
                model.addAttribute("action", "edit");
                return getAutoUrl("form");
            }
        }
    }

    /**
     * 查询CmAddGoods
     *
     * @param request 请求对象
     * @return 结果视图
     */
    @RequestMapping(value = "", method = RequestMethod.GET)
    public String list(Integer number, Model model, HttpServletRequest request) {
        // 获取查询条件
        Map<String, Object> searchParams = Servlets.getParametersStartingWith(request, "search_");
        Page page = new Page(Page.TWENTY_PAGE_SIZE);
        if (null != number) {
            page.setCurrentPage(number);
        }
        CmAddGoodsListRequest listRequest = new CmAddGoodsListRequest();
        listRequest.setPaging(page);
        listRequest.setSearchParams(searchParams);
        CmAddGoodsListResponse response = cmAddGoods.getCmAddGoodsList(listRequest);
        model.addAttribute("page", response.getPaging());
        model.addAttribute("cmAddGoodss", response.getObjectList());
        model.addAttribute("searchParams", Servlets.encodeParameterStringWithPrefix(searchParams, "search_"));
        return getAutoUrl();
    }

}
