/**
 * Description: CmReplyPraise控制器
 * Copyright:   Copyright (c)2015
 * Company:     江苏三六五网络股份有限公司
 * @author:     江苏三六五网络股份有限公司
 * @version:    1.0
 * Create at:   2015-08-11 上午 09:31:52
 *  
 * Modification History:
 * Date         Author      Version     Description
 * ------------------------------------------------------------------
 * 2015-08-11   江苏三六五网络股份有限公司   1.0         Initial
 */
package com.house365.web.controller;

import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.validation.Valid;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseStatus;
import org.springframework.web.servlet.mvc.support.RedirectAttributes;
import org.springside.modules.web.Servlets;

import com.house365.beans.system.Page;

import com.house365.beans.entity.CmReplyPraiseEntity;
import com.house365.beans.vo.CmReplyPraiseVo;

import com.house365.web.system.controller.BaseController;
import com.house365.web.util.StringUtils;
import com.house365.ws.beans.response.CmBrokerLabelResponse;

import com.house365.ws.beans.request.CmReplyPraiseListRequest;
import com.house365.ws.beans.request.CmReplyPraiseRequest;
import com.house365.ws.beans.response.CmReplyPraiseListResponse;
import com.house365.ws.beans.response.CmReplyPraiseResponse;
import com.house365.ws.interfaces.server.ICmReplyPraise;

/**
 * CmReplyPraise控制器<br>
 * 
 * @author 江苏三六五网络股份有限公司
 * @version 1.0, 2015-08-11
 * @see
 * @since 1.0
 */
@Controller
@RequestMapping("/cmreplypraise")
public class CmReplyPraiseController extends BaseController {

	/**
	 * 自动注入CmReplyPraiseWS实现
	 */
	@Autowired
	private ICmReplyPraise cmReplyPraise;

	/**
	 * 去新增CmReplyPraise
	 * 
	 * @return 结果视图
	 */
	@RequestMapping(value = "", params = "action=create")
	public String createForm(Model model){
		model.addAttribute("action", "create");
		return getAutoUrl("form");
	}

	/**
	 * 新增CmReplyPraise
	 * 
	 * @param cmReplyPraise CmReplyPraise页面表单对象
	 * @param result 表单验证数据
	 * @param page 分页配置
	 * @param request 请求对象
	 * @return 结果视图
	 */
	@RequestMapping(value = "", method = { RequestMethod.POST})
	public String createCmReplyPraise(@Valid CmReplyPraiseVo vo, BindingResult result, RedirectAttributes redirectAttributes, Model model){
		CmReplyPraiseEntity entity = vo.getEntity();
		model.addAttribute("entity", entity);
		// subValidation(result, entity);
		// 表单验证无误,进行提交
		if (result.hasErrors()) {
		    model.addAttribute("action", "create");
            addErrorMessage(model, result.getFieldError().getDefaultMessage());
            return getAutoUrl("form");
		} else {
		    try {
                CmReplyPraiseRequest request = new CmReplyPraiseRequest();
                request.setEntity(entity);
                CmReplyPraiseResponse response = cmReplyPraise
                        .addCmReplyPraise(request);
                Integer id = response.getEntity().getId();
                return "redirect:/cmreplypraise/" + id;
            } catch (Exception ex) {
                addErrorMessage(model, ex.getMessage());
                model.addAttribute("action", "create");
                return getAutoUrl("form");
            }
		}
	}

	/**
	 * 删除CmReplyPraise
	 * 
	 * @param id CmReplyPraise页面表单对象唯一标识
	 * @param page 分页配置
	 * @param request 请求对象
	 * @return 结果视图
	 */
	@RequestMapping(value = "/{id}", method = { RequestMethod.DELETE })
	@ResponseStatus(HttpStatus.OK)
	public void delete(@PathVariable String id){
	    if(!StringUtils.isEmpty(id))
        {
            if(id.contains(","))
            {
                String[] ids = id.split(",");
                for (int i = 0; i < ids.length; i++) {
                    CmReplyPraiseResponse response = cmReplyPraise.deleteCmReplyPraiseById(Integer.valueOf(ids[i]));
                }
            }
            else
            {
                CmReplyPraiseResponse response = cmReplyPraise.deleteCmReplyPraiseById(Integer.valueOf(id));
            }
        }
	}

	/**
	 * 去查看CmReplyPraise
	 * 
	 * @param id
	 *            CmReplyPraise页面表单对象唯一标识
	 * @param request
	 *            请求对象
	 * @return 结果视图
	 */
	@RequestMapping(value = "/{id}", method = { RequestMethod.GET })
	public String showForm(@PathVariable(value = "id") Integer id, Model model) {
        CmReplyPraiseResponse response = cmReplyPraise
                .getCmReplyPraiseById(id);
        model.addAttribute("entity", response.getEntity());
        return getAutoUrl("form");
	}

	/**
	 * 去修改CmReplyPraise
	 * 
	 * @param id CmReplyPraise页面表单对象唯一标识
	 * @param request 请求对象
	 * @return 结果视图
	 */
	@RequestMapping(value = "/{id}", method = { RequestMethod.GET}, params = "action=edit")
	public String updateForm(@PathVariable(value = "id") Integer id, Model model){
        CmReplyPraiseResponse response = cmReplyPraise
                .getCmReplyPraiseById(id);
        model.addAttribute("entity", response.getEntity());
		model.addAttribute("action", "edit");
		return getAutoUrl("form");
	}

	/**
	 * 修改CmReplyPraise
	 * 
	 * @param cmReplyPraise CmReplyPraise页面表单对象
	 * @param result 表单验证数据
	 * @param page 分页配置
	 * @param request 请求对象
	 * @return 结果视图
	 */
	@RequestMapping(value = "/{id}", method = { RequestMethod.POST})
	public String updateCmReplyPraise(@Valid CmReplyPraiseVo vo, BindingResult result, @PathVariable Integer id, RedirectAttributes redirectAttributes, Model model){
		CmReplyPraiseEntity entity = vo.getEntity();
		model.addAttribute("entity", entity);
		// subValidation(result, entity);
		// 表单验证无误,进行提交
		if (result.hasErrors()) {
		    model.addAttribute("action", "create");
            addErrorMessage(model, result.getFieldError().getDefaultMessage());
            return getAutoUrl("form");
		} else {
            try {
                CmReplyPraiseRequest request = new CmReplyPraiseRequest();
                request.setEntity(entity);
                @SuppressWarnings("unused")
                CmReplyPraiseResponse rersponse = cmReplyPraise
                        .updateCmReplyPraise(request);
                redirectAttributes.addAttribute("message", "更新成功");
                return "redirect:/cmreplypraise/" + entity.getId();
            } catch (Exception ex) {
                addErrorMessage(model, ex.getMessage());
                model.addAttribute("action", "edit");
                return getAutoUrl("form");
            }
		}
	}

	/**
	 * 查询CmReplyPraise
	 * 
	 * @param cmReplyPraise CmReplyPraise页面表单对象
	 * @param page 分页配置
	 * @param request 请求对象
	 * @return 结果视图
	 */
	@RequestMapping(value = "", method = RequestMethod.GET)
	public String list (Integer number, Model model, HttpServletRequest request) {
		// 获取查询条件
		Map<String, Object> searchParams = Servlets.getParametersStartingWith(
				request, "search_");
		Page page = new Page(Page.TWENTY_PAGE_SIZE);
		if (null != number) {
			page.setCurrentPage(number);
		}
		CmReplyPraiseListRequest listRequest = new CmReplyPraiseListRequest();
        listRequest.setPaging(page);
        listRequest.setSearchParams(searchParams);
        CmReplyPraiseListResponse response = cmReplyPraise.getCmReplyPraiseList(listRequest);
        model.addAttribute("page", response.getPaging());
        model.addAttribute("cmReplyPraises", response.getObjectList());
        model.addAttribute("searchParams", Servlets
                .encodeParameterStringWithPrefix(searchParams, "search_"));
		return getAutoUrl();
	}
}
